#!/usr/local/bin/perl

# Copyright (c) 1998 Daniel J. Gregor, Jr., All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. All advertising materials mentioning features or use of this software
#    must display the following acknowledgement:
# 	This product includes software developed by Daniel J. Gregor, Jr.
# 4. The name of Daniel J. Gregor, Jr. may not be used to endorse or promote
#    products derived from this software without specific prior written
#    permission.
# 
# THIS SOFTWARE IS PROVIDED BY DANIEL J. GREGOR, JR. ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL DANIEL J. GREGOR, JR. BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

use DBI;

%maptocolumn = (
	'banner' => 'banner',
	'Unit Name' => 'unit_name',
	'Council Name' => 'council_name',
	'address' => 'address',
	'city' => 'city',
	'state' => 'state',
	'country' => 'country',
	'zip' => 'zip',
	'language' => 'language',
	'phone' => 'phone',
	'tollfree' => 'tollfree',
	'fax' => 'fax',
	'first_name' => 'first_name',
	'last_name' => 'last_name',
	'email' => 'email',
	'url' => 'url',
	'title' => 'title',
	'description' => 'description',
	'How' => 'how',
);

while (<>) {
	chomp();

	last if m/^$/;
	last if m/^banner=/;
}

while (<>) {
	chomp();

	next if m/^\s*$/;
	last if m/^How=/;
	m/^([^=]+)=(.*)$/ || die "poorly formatted line: \"$_\"";

	exists($maptocolumn{$1}) || die "unknown key $1";

	if (exists($info{$1})) { 
		$info{$maptocolumn{$1}} = $info{$maptocolumn{$1}} . " " . $2;
	} else {
		$info{$maptocolumn{$1}} = $2;
	}
}

$database = "stwa";

$dbh = DBI->connect("dbi:Pg:dbname=$database", "", "", { 'AutoCommit' => 0 })
	|| die "cannot open DB: $!\n";

@columns = ();
@values = ();

foreach $i (keys(%info)) {
#	print "$i: $info{$i}\n";
	push(@columns, $i);
	if ($info{$i} =~ m/^$/) {
		push(@values, "NULL");
	} else {
		push(@values, $dbh->quote($info{$i}));
	}
}

push(@columns, "date");
push(@values, "'now'");

$statement = "INSERT INTO nomination " .
	" ( " .  join(", ", @columns) . " ) " .
	" VALUES ( " .  join(", ", @values) . " ) ";

#print $statement, "\n";

$sth = $dbh->prepare($statement);
$sth || die "error: $dbh->errstr";
$sth->execute || die "cannot execute statement: $!";
$dbh->commit || die "cannot commit";

$dbh->disconnect();
